import socket

from pmxbot.core import command


@command("resolv", doc="resolve a hostname")
def resolve(rest):
    """
    >>> resolve("localhost")
    '...'
    """
    return socket.getfqdn(rest)



import re

import twilio.rest
import pmxbot
from pmxbot.core import command


from_number = '+15712573984'


@command()
def send_text(rest):
    """
    Send an SMS message: pass the phone number and message to send.
    """
    account = pmxbot.config.twilio_account
    token = pmxbot.config.twilio_token
    number, _, msg = rest.partition(' ')
    number = parse_number(number)
    if not msg:
        return
    msg = msg.encode('ascii')[:160]
    client = twilio.rest.Client(username=account, password=token)
    client.messages.create(to=number, from_=from_number, body=msg)
    return "Sent {count} chars to {number}".format(
        count=len(msg),
        number=number,
    )


def parse_number(input_):
    """
    Strip everything but digits and + sign; ensure it begins with a country
    code.

    >>> parse_number('5555551212')
    '+15555551212'
    >>> parse_number('12025551212')
    '+12025551212'
    >>> parse_number('+44')
    '+44'
    """
    clean = ''.join(re.findall(r'[\d+]*', input_))
    if not clean.startswith('+'):
        clean = clean.lstrip('1')
        clean = '+1' + clean
    return clean



import pytest
import pmxbot
from jaraco.collections import ItemsAsAttributes

from jaraco.pmxbot import notification


@pytest.fixture
def twilio_test_credentials(monkeypatch):
    class ConfigDict(ItemsAsAttributes, dict):
        pass

    monkeypatch.setattr(pmxbot, 'config', ConfigDict(), raising=False)
    monkeypatch.setitem(
        pmxbot.config,
        'twilio_account',
        'ACa3ea172f6b198b5f030c160518460f19',
    )
    monkeypatch.setitem(
        pmxbot.config,
        'twilio_token',
        'd011e427bff04fdf56987aeb77aadeb4',
    )
    monkeypatch.setattr(notification, 'from_number', '+15005550006')


def test_send_text(twilio_test_credentials):
    res = notification.send_text(rest='+12026837967 <3 pmxbot')
    assert res == 'Sent 9 chars to +12026837967'


def test_no_message(twilio_test_credentials):
    assert not notification.send_text(rest='')
